==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/in/vin205.cpp <==
/*!================================================================

 module:        vin205.cpp

 -------------------------------------------------------------------

 responsible:   DanielD

 special area:  SQL

 description:   RequestWriter

 -------------------------------------------------------------------

 copyright:     SAP AG 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 ===================================================================*/

#include "hsp77.h"
#include "hin205.h"

/*----------------------------------------*/

cin205_RequestWriter::cin205_RequestWriter (cin203_RequestPacket packetParm)
   : packet (packetParm)
{
}

/*----------------------------------------*/

cin205_RequestWriter::~cin205_RequestWriter ()
{
}

/*----------------------------------------*/

void cin205_RequestWriter::Reset ()
{
    this->part.Invalidate ();
    this->segment.Invalidate ();
    this->packet.Reset ();
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
    /* PTS 1112792 parsingAgain added */
cin202_RequestSegment * cin205_RequestWriter::AddSegment (tsp1_cmd_mess_type_Param messType,
                                                          const tsp1_sqlmode_Enum &sqlMode,
                                                          const pasbool parsingAgain )
{
    this->CloseSegment ();
    /* PTS 1108446 sqlMode added */
    /* PTS 1112792 parsingAgain added */
    this->segment = this->packet.AddSegment (messType, sqlMode, parsingAgain ); 
    return &this->segment;
}

/*----------------------------------------*/

void cin205_RequestWriter::CloseSegment ()
{
    if (this->segment.IsValid ()) {
        this->ClosePart ();
        this->packet.CloseSegment (this->segment);
        this->segment.Invalidate ();
    }
}

/*----------------------------------------*/

cin201_Part * cin205_RequestWriter::AddPart (tsp1_part_kind_Param partKind)
{
    this->ClosePart ();
    this->part = this->segment.AddPart (partKind);
    return &this->part;
}

/*----------------------------------------*/

void cin205_RequestWriter::ClosePart ()
{
    if (this->part.IsValid ()) {
        this->segment.ClosePart (this->part);
        this->part.Invalidate ();
    }
}

/*----------------------------------------*/

void cin205_RequestWriter::Close ()
{
    this->CloseSegment ();
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
/* PTS 1112792 parsingAgain added */
cin201_Part * cin205_RequestWriter::InitDbs (const tsp1_sqlmode_Enum &sqlMode, 
                                             const char *cmd, 
                                             int len,
                                             const pasbool parsingAgain )
{
  if (len == -1) {
      len = (int)strlen (cmd);
  }
  /* PTS 1108446 sqlMode added */
  /* PTS 1112792 parsingAgain added */
  this->AddSegment (sp1m_dbs, sqlMode, parsingAgain );   
  this->AddPart (sp1pk_command);
  this->part.AddArgument (cmd, len);
  return &this->part;
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
/* PTS 1112792 parsingAgain added */
cin201_Part * cin205_RequestWriter::InitDbs (const tsp1_sqlmode_Enum &sqlMode,
                                             const tsp81_UCS2Char *cmd, 
                                             int len,
                                             const pasbool parsingAgain )
{
  if (len == -1) {
      len = (int)sp81UCS2strlen (cmd) * sizeof(tsp81_UCS2Char);
  }
  /* PTS 1108446 sqlMode added */
  /* PTS 1112792 parsingAgain added */
  this->AddSegment (sp1m_dbs, sqlMode, parsingAgain );   
  this->AddPart (sp1pk_command);
  this->part.AddArgument ((char*)cmd, len);
  return &this->part;
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
/* PTS 1112792 parsingAgain added */
cin201_Part * cin205_RequestWriter::InitDbsf (const tsp1_sqlmode_Enum &sqlMode,
                                              const pasbool parsingAgain,
                                              const char *fmt, ...)
{
    va_list ap;

    va_start (ap, fmt);
    /* PTS 1108446 sqlMode added */
    /* PTS 1112792 parsingAgain added */
    this->AddSegment (sp1m_dbs, sqlMode, parsingAgain );   
    this->AddPart (sp1pk_command);
    this->VPrintf (fmt, ap);
    va_end (ap);
    return &this->part;
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
/* PTS 1112792 parsingAgain added */
cin201_Part * cin205_RequestWriter::InitParse (const tsp1_sqlmode_Enum &sqlMode,
                                               const char *cmd, 
                                               int len,
                                               const pasbool parsingAgain )
{
  if (len == -1) 
    len = (int)strlen (cmd);
  /* PTS 1108446 sqlMode added */
  /* PTS 1112792 parsingAgain added */
  this->AddSegment (sp1m_parse, sqlMode, parsingAgain);   
  this->AddPart (sp1pk_command);
  this->part.AddArgument (cmd, len);
  return &this->part;
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
/* PTS 1112792 parsingAgain added */
cin201_Part * cin205_RequestWriter::InitParse (const tsp1_sqlmode_Enum &sqlMode,
                                               const tsp81_UCS2Char *cmd, 
                                               int len,
                                               const pasbool parsingAgain )
{
  if (len == -1) 
    len = (int)sp81UCS2strlen (cmd) * sizeof(tsp81_UCS2Char);
  /* PTS 1108446 sqlMode added */
  /* PTS 1112792 parsingAgain added */
  this->AddSegment (sp1m_parse, sqlMode, parsingAgain);   
  this->AddPart (sp1pk_command);
  this->part.AddArgument ((char*)cmd, len);
  return &this->part;
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
/* PTS 1112792 parsingAgain added */
cin201_Part * cin205_RequestWriter::InitParsef (const tsp1_sqlmode_Enum &sqlMode,
                                                const pasbool parsingAgain,
                                                const char *fmt, ...)
{
    va_list ap;

    va_start (ap, fmt);
    /* PTS 1108446 sqlMode added */
    /* PTS 1112792 parsingAgain added */
    this->AddSegment (sp1m_parse, sqlMode, parsingAgain);   
    this->AddPart (sp1pk_command);
    this->VPrintf (fmt, ap);
    va_end (ap);
    return &this->part;
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
void cin205_RequestWriter::InitExecute (const tsp1_sqlmode_Enum &sqlMode,
                                        const tin02_ParseId * parseId)
{
    this->AddSegment (sp1m_execute, sqlMode);   /* PTS 1108446 sqlMode added */
    this->AddPart (sp1pk_command);
    this->part.AddArgument (parseId, sizeof (tin02_ParseId));
}

/*----------------------------------------*/

cin201_Part * cin205_RequestWriter::AddDataPart ()
{
    this->AddPart (sp1pk_data);
    return &this->part;
}

/*----------------------------------------*/

int cin205_RequestWriter::VPrintf (const char *fmt, va_list ap)
{
    char * writeBuf;
    int commandLen;
    int bytesRemaining;

    writeBuf = REINTERPRET_CAST (char *, this->part.GetWriteData ());
    bytesRemaining = this->part.BytesRemaining ();
    commandLen = sp77vsprintf (writeBuf, bytesRemaining, fmt, ap);
    if (commandLen > 0) {
        this->part.ExtendLength (commandLen);
        this->part.AddArgument (NULL, -1);
    }
    return commandLen;
}

/*----------------------------------------*/

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/in/vin205.cpp <==
/*!================================================================

 module:        vin205.cpp

 -------------------------------------------------------------------

 responsible:   DanielD

 special area:  SQL

 description:   RequestWriter

 -------------------------------------------------------------------

 copyright:     SAP AG 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 ===================================================================*/

#include "hsp77.h"
#include "hin205.h"

/*----------------------------------------*/

cin205_RequestWriter::cin205_RequestWriter (cin203_RequestPacket packetParm)
   : packet (packetParm)
{
}

/*----------------------------------------*/

cin205_RequestWriter::~cin205_RequestWriter ()
{
}

/*----------------------------------------*/

void cin205_RequestWriter::Reset ()
{
    this->part.Invalidate ();
    this->segment.Invalidate ();
    this->packet.Reset ();
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
    /* PTS 1112690 parsingAgain added */
cin202_RequestSegment * cin205_RequestWriter::AddSegment (tsp1_cmd_mess_type_Param messType,
                                                          const tsp1_sqlmode_Enum &sqlMode,
                                                          const pasbool parsingAgain )
{
    this->CloseSegment ();
    /* PTS 1108446 sqlMode added */
    /* PTS 1112690 parsingAgain added */
    this->segment = this->packet.AddSegment (messType, sqlMode, parsingAgain ); 
    return &this->segment;
}

/*----------------------------------------*/

void cin205_RequestWriter::CloseSegment ()
{
    if (this->segment.IsValid ()) {
        this->ClosePart ();
        this->packet.CloseSegment (this->segment);
        this->segment.Invalidate ();
    }
}

/*----------------------------------------*/

cin201_Part * cin205_RequestWriter::AddPart (tsp1_part_kind_Param partKind)
{
    this->ClosePart ();
    this->part = this->segment.AddPart (partKind);
    return &this->part;
}

/*----------------------------------------*/

void cin205_RequestWriter::ClosePart ()
{
    if (this->part.IsValid ()) {
        this->segment.ClosePart (this->part);
        this->part.Invalidate ();
    }
}

/*----------------------------------------*/

void cin205_RequestWriter::Close ()
{
    this->CloseSegment ();
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
/* PTS 1112690 parsingAgain added */
cin201_Part * cin205_RequestWriter::InitDbs (const tsp1_sqlmode_Enum &sqlMode, 
                                             const char *cmd, 
                                             int len,
                                             const pasbool parsingAgain )
{
  if (len == -1) {
      len = (int)strlen (cmd);
  }
  /* PTS 1108446 sqlMode added */
  /* PTS 1112690 parsingAgain added */
  this->AddSegment (sp1m_dbs, sqlMode, parsingAgain );   
  this->AddPart (sp1pk_command);
  if ( len > this->part.BytesRemaining ()) return NULL;
  this->part.AddArgument (cmd, len);
  return &this->part;
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
/* PTS 1112690 parsingAgain added */
cin201_Part * cin205_RequestWriter::InitDbs (const tsp1_sqlmode_Enum &sqlMode,
                                             const tsp81_UCS2Char *cmd, 
                                             int len,
                                             const pasbool parsingAgain )
{
  if (len == -1) {
      len = (int)sp81UCS2strlen (cmd) * sizeof(tsp81_UCS2Char);
  }
  /* PTS 1108446 sqlMode added */
  /* PTS 1112690 parsingAgain added */
  this->AddSegment (sp1m_dbs, sqlMode, parsingAgain );   
  this->AddPart (sp1pk_command);
  if ( len > this->part.BytesRemaining ()) return NULL;
  this->part.AddArgument ((char*)cmd, len);
  return &this->part;
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
/* PTS 1112690 parsingAgain added */
cin201_Part * cin205_RequestWriter::InitDbsf (const tsp1_sqlmode_Enum &sqlMode,
                                              const pasbool parsingAgain,
                                              const char *fmt, ...)
{
    va_list ap;
    int     cmdlen;

    va_start (ap, fmt);
    /* PTS 1108446 sqlMode added */
    /* PTS 1112690 parsingAgain added */
    this->AddSegment (sp1m_dbs, sqlMode, parsingAgain );   
    this->AddPart (sp1pk_command);
    cmdlen = this->VPrintf (fmt, ap);
    va_end (ap);
    if ( cmdlen )
      return &this->part;
    else
      return NULL;
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
/* PTS 1112690 parsingAgain added */
cin201_Part * cin205_RequestWriter::InitParse (const tsp1_sqlmode_Enum &sqlMode,
                                               const char *cmd, 
                                               int len,
                                               const pasbool parsingAgain )
{
  if (len == -1) 
    len = (int)strlen (cmd);
  /* PTS 1108446 sqlMode added */
  /* PTS 1112690 parsingAgain added */
  this->AddSegment (sp1m_parse, sqlMode, parsingAgain);   
  this->AddPart (sp1pk_command);
  if ( len > this->part.BytesRemaining ()) return NULL;
  this->part.AddArgument (cmd, len);
  return &this->part;
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
/* PTS 1112690 parsingAgain added */
cin201_Part * cin205_RequestWriter::InitParse (const tsp1_sqlmode_Enum &sqlMode,
                                               const tsp81_UCS2Char *cmd, 
                                               int len,
                                               const pasbool parsingAgain )
{
  if (len == -1) 
    len = (int)sp81UCS2strlen (cmd) * sizeof(tsp81_UCS2Char);
  /* PTS 1108446 sqlMode added */
  /* PTS 1112690 parsingAgain added */
  this->AddSegment (sp1m_parse, sqlMode, parsingAgain);   
  this->AddPart (sp1pk_command);
  if ( len > this->part.BytesRemaining ()) return NULL;
  this->part.AddArgument ((char*)cmd, len);
  return &this->part;
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
/* PTS 1112690 parsingAgain added */
cin201_Part * cin205_RequestWriter::InitParsef (const tsp1_sqlmode_Enum &sqlMode,
                                                const pasbool parsingAgain,
                                                const char *fmt, ...)
{
    va_list ap;
    int     cmdlen;

    va_start (ap, fmt);
    /* PTS 1108446 sqlMode added */
    /* PTS 1112690 parsingAgain added */
    this->AddSegment (sp1m_parse, sqlMode, parsingAgain);   
    this->AddPart (sp1pk_command);
    cmdlen = this->VPrintf (fmt, ap);
    va_end (ap);
    if ( cmdlen )
      return &this->part;
    else
      return NULL;
}

/*----------------------------------------*/

/* PTS 1108446 sqlMode added */
void cin205_RequestWriter::InitExecute (const tsp1_sqlmode_Enum &sqlMode,
                                        const tin02_ParseId * parseId)
{
    this->AddSegment (sp1m_execute, sqlMode);   /* PTS 1108446 sqlMode added */
    this->AddPart (sp1pk_command);
    this->part.AddArgument (parseId, sizeof (tin02_ParseId));
}

/*----------------------------------------*/

cin201_Part * cin205_RequestWriter::AddDataPart ()
{
    this->AddPart (sp1pk_data);
    return &this->part;
}

/*----------------------------------------*/

int cin205_RequestWriter::VPrintf (const char *fmt, va_list ap)
{
    char * writeBuf;
    int commandLen;
    int bytesRemaining;

    writeBuf = REINTERPRET_CAST (char *, this->part.GetWriteData ());
    bytesRemaining = this->part.BytesRemaining ();
    commandLen = sp77vsprintf (writeBuf, bytesRemaining, fmt, ap);
    if ( commandLen >= bytesRemaining) return 0;
    if (commandLen > 0) {
        this->part.ExtendLength (commandLen);
        this->part.AddArgument (NULL, -1);
    }
    return commandLen;
}

/*----------------------------------------*/
